﻿local name, addon = ...;
local regionID = GetCurrentRegion();
local FLAG = "|cffff0000(" .. GetText("PVP") .. ")|r ";

-- Patch result name with the pvp flag
local function setPvpFlagOnEntry(entry, name, ...)
	entry.Name:SetText(FLAG .. name);
end

local function getRealmName(leaderName)
	local i, _ = string.find(leaderName, "-", 0, true);
	if (i) then
		return string.sub(leaderName, i + 1);
	else
		return nil;
	end
end

local function isPvpRealm(realmName)
	if (realmName) then
		for _, value in pairs(addon.realms[regionID]) do
			if value == realmName then
				return true
			end
		end
	end
	return false
end

local function hook_LFGListSearchEntry_Update(entry, ...)
	local resultID = entry.resultID;
	local _, _, name, _, _, _, _, _, _, _, _, _, leaderName = C_LFGList.GetSearchResultInfo(resultID);

	if (leaderName) then
		local realmName = getRealmName(leaderName);
		if (realmName and isPvpRealm(realmName)) then
			setPvpFlagOnEntry(entry, name, ...);
		end
	end
end

-- Init
local function Init(...)
	local addonName = select(3, ...);
	
	if (addonName == "WarnMeAboutPvP") then
		WMAP_Frame:UnregisterAllEvents()
		
		if (addon.realms[regionID]) then
			hooksecurefunc("LFGListSearchEntry_Update", hook_LFGListSearchEntry_Update);
		else
			print("WarnMeAboutPvP : your region is not supported, functionality disabled.");
		end
	end
end		

-- Bootstrap
local WMAP_Frame = CreateFrame("Frame", "WMAP_Frame", UIParent);
WMAP_Frame:SetScript("OnEvent", Init);
WMAP_Frame:RegisterEvent("ADDON_LOADED");
